[![last commit](https://img.shields.io/github/last-commit/SantosVilanculos/rokugu)](https://github.com/SantosVilanculos/rokugu/commits/main)
[![license](https://img.shields.io/github/license/SantosVilanculos/rokugu)](https://github.com/SantosVilanculos/rokugu/blob/main/LICENSE)
[![pypi](https://img.shields.io/pypi/v/rokugu)](https://pypi.org/project/rokugu)

![screenshot](https://raw.githubusercontent.com/SantosVilanculos/rokugu/main/screenshot.png)
